<?php

/* Load the core theme framework. */
require_once( trailingslashit( get_template_directory() ) . 'library/framework.php' );
new Framework();

/* Do theme setup on the 'after_setup_theme' hook. */
add_action( 'after_setup_theme', 'framework_theme_setup_theme' );

/* Theme setup function. */
function framework_theme_setup_theme() {
	global $content_width;

	/* Content width. */
	if ( empty( $content_width ) && !is_active_sidebar( 'primary' ) && !is_active_sidebar( 'secondary' ) )
		$content_width = 1024;
	elseif ( empty( $content_width ) )
		$content_width = 680;

	/* Get the theme prefix. */
	$prefix = framework_get_prefix();

	/* Add support for theme features. */
	add_theme_support( 'cleaner-caption' );
	add_theme_support( 'cleaner-gallery' );
	add_theme_support( 'loop-pagination' );
	add_theme_support( 'nav-menus', array( 'primary', 'subsidiary' ) );
	add_theme_support( 'theme-layouts', array( '1c', '2c-r' ) );
	add_theme_support( 'widget-areas', array( 'primary', 'secondary', 'subsidiary', 'subsidiary-4c', 'shelf', 'error-404-template' ) );

	/* Register image sizes. */
	add_action( 'init', 'framework_register_image_sizes' );

	/* Add the menus. */
	add_action( "{$prefix}_before_main", 'framework_get_primary_menu' );
	add_action( "{$prefix}_after_main", 'framework_get_subsidiary_menu' );

	/* Add the sidebars. */
	add_action( "{$prefix}_before_footer", 'framework_get_subsidiary_sidebar' );
	add_action( "{$prefix}_before_footer", 'framework_get_subsidiary_4c_sidebar' );
	add_action( "{$prefix}_open_body", 'framework_get_shelf_sidebar' );

	/* Add the footer insert to the footer. */
	add_action( "{$prefix}_footer", 'framework_footer_insert' );

	/* Add the custom CSS. */
	add_action( 'wp_head', 'framework_custom_css' );

	/* Add the filter function to the 'oembed_dataparse' filter hook. */
	add_filter( 'oembed_dataparse', 'framework_oembed_wrapper', 90, 3 );

	/* Add classes to the comments pagination. */
	add_filter( 'next_comments_link_attributes', 'framework_next_comment_link_attributes' );
	add_filter( 'previous_comments_link_attributes', 'framework_previous_comment_link_attributes' );

}

/* Add image sizes. */
function framework_register_image_sizes() {
	add_image_size( 'post-image', 960, 99999 );
	add_image_size( 'post-thumb', 125, 125, true );
	add_image_size( 'slideshow-image', 960, 500, true );
}

/* Load the menus. */
function framework_get_primary_menu() { get_template_part( 'menu-primary' ); }
function framework_get_subsidiary_menu() { get_template_part( 'menu-subsidiary' ); }

/* Load the sidebars. */
function framework_get_subsidiary_sidebar() { get_sidebar( 'subsidiary' ); }
function framework_get_subsidiary_4c_sidebar() { get_sidebar( 'subsidiary-4c' ); }
function framework_get_shelf_sidebar() { get_sidebar( 'shelf' ); }

/* Displays the footer insert from the theme settings page. */
function framework_footer_insert() {
	$footer_insert = framework_get_setting( 'footer_insert' );

	if ( !empty( $footer_insert ) )
		echo '<div class="footer-content footer-insert">' . do_shortcode( $footer_insert ) . '</div>';
}

/* Load the custom CSS. */
function framework_custom_css() {
	$custom_css = framework_get_setting( 'custom_css' );

	if ( $custom_css ) :

		echo "\n" . '<!-- Custom CSS -->';
		echo "\n" . '<style type="text/css">' . "\n";

			echo $custom_css . "\n";

		echo '</style>' . "\n";

	endif;
}

/* Wrap all oEmbedded videos with a p tag. */
function framework_oembed_wrapper( $output, $data, $url ) {
	$return = '<p class="entry-video">' . $output . '</p><!-- .entry-video -->';
	return $return;
}

/* Adds 'class="next" to the next comment link. */
function framework_next_comment_link_attributes( $attributes ) {
	return $attributes . ' class="next"';
}

/* Adds 'class="prev" to the previous comment link. */
function framework_previous_comment_link_attributes( $attributes ) {
	return $attributes . ' class="prev"';
}

?>