<?php

/* Add a new meta box to the post editor. */
add_action( 'admin_menu', 'framework_create_post_meta_box' );

/* Saves the post meta box data. */
add_action( 'save_post', 'framework_save_post_meta_box' );

/* Creates a meta box on the post (page, other post types) editing screen. */
function framework_create_post_meta_box() {

	/* Get the theme prefix. */
	$prefix = framework_get_prefix();

	/* For each post type specified, create a meta box on its edit page. */
	add_meta_box( 'framework-post-meta-box', sprintf( __( 'Post Settings', 'wordsmith' ) ), 'framework_post_meta_box', 'post', 'normal', 'high' );

}

/* Creates the settings for the post meta box. */
function framework_post_meta_box_args( $type = '' ) {

	/* Get the theme prefix. */
	$prefix = framework_get_prefix();

	if ( empty( $type ) ) $type = 'post';

	/* Post Settings */
	if ( $type == 'post' ) {

		/* MP3 URL for audio post format. */
		$meta['_mp3_url'] = array(
			'name' => '_mp3_url',
			'title' => __( 'MP3 URL:', 'wordsmith' ),
			'description' => __( 'Input the full URL to your audio file, only used for the Audio post format.', 'wordsmith' ),
			'type' => 'text'
		);

	}

	$meta = apply_filters( "{$prefix}_{$type}_meta_boxes", $meta );
	return apply_filters( "{$prefix}_{$type}_meta_box_args", $meta );

}

/* Displays the post meta box on the edit post page. */
function framework_post_meta_box( $object, $box ) {

	/* Get the theme prefix. */
	$prefix = framework_get_prefix();

	$meta_box_options = framework_post_meta_box_args( $object->post_type );

?>

<input type="hidden" name="<?php echo "{$prefix}_{$object->post_type}_meta_box_nonce"; ?>" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

<table class="form-table">

	<?php
		foreach ( $meta_box_options as $option ) {
		if ( function_exists( "framework_post_meta_box_{$option['type']}" ) )
		call_user_func( "framework_post_meta_box_{$option['type']}", $option, get_post_meta( $object->ID, $option['name'], true ) ); }
	?>

</table><!-- .form-table -->

<?php }

/* Outputs radio inputs with the given arguments for use with the post meta box. */
function framework_post_meta_box_radio( $args = array(), $value = false ) {
	$name = preg_replace( "/[^A-Za-z_-]/", '-', $args['name'] ); ?>

	<tr>
		<th>
			<?php if ( $args['description'] ) : ?>
				<label for="<?php echo $name; ?>"><strong><?php echo $args['title']; ?></strong></label>
				<p class="description"><?php echo $args['description']; ?></p>
			<?php else : ?>
				<label for="<?php echo $name; ?>"><?php echo $args['title']; ?></label>
			<?php endif; ?>
		</th>

		<td>
			<?php foreach ( $args['options'] as $option => $val ) { ?>
				<input <?php if ( htmlentities( $value, ENT_QUOTES ) == $val ) echo ' checked="checked"'; ?> name="<?php echo $name; ?>" type="radio" value="<?php echo $val; ?>" /> <?php echo $val; ?> 
			<?php } ?>
		</td>
	</tr>

<?php }

/* Outputs a select box with the given arguments for use with the post meta box. */
function framework_post_meta_box_select( $args = array(), $value = false ) {
	$name = preg_replace( "/[^A-Za-z_-]/", '-', $args['name'] ); ?>

	<tr>
		<th>
			<?php if ( $args['description'] ) : ?>
				<label for="<?php echo $name; ?>"><strong><?php echo $args['title']; ?></strong></label>
				<p class="description"><?php echo $args['description']; ?></p>
			<?php else : ?>
				<label for="<?php echo $name; ?>"><?php echo $args['title']; ?></label>
			<?php endif; ?>
		</th>

		<td>
			<select id="<?php echo $name; ?>" name="<?php echo $name; ?>">
				<option value=""></option>
				<?php foreach ( $args['options'] as $option => $val ) : ?>
					<option <?php if ( htmlentities( $value, ENT_QUOTES ) == $val ) echo ' selected="selected"'; ?> value="<?php echo $val; ?>"><?php if ( $args['use_key_and_value'] ) echo $option; else echo $val; ?></option>
				<?php endforeach; ?>
			</select>
		</td>
	</tr>

<?php }

/* Outputs a text input box with the given arguments for use with the post meta box. */
function framework_post_meta_box_text( $args = array(), $value = false ) {
	$name = preg_replace( "/[^A-Za-z_-]/", '-', $args['name'] ); ?>

	<tr>
		<th>
			<?php if ( $args['description'] ) : ?>
				<label for="<?php echo $name; ?>"><strong><?php echo $args['title']; ?></strong></label>
				<p class="description"><?php echo $args['description']; ?></p>
			<?php else : ?>
				<label for="<?php echo $name; ?>"><?php echo $args['title']; ?></label>
			<?php endif; ?>
		</th>

		<td>
			<input id="<?php echo $name; ?>" name="<?php echo $name; ?>" type="text" value="<?php echo esc_html( $value, 1 ); ?>" size="30" tabindex="30" style="width: 100%;" />	
		</td>
	</tr>

<?php }

/* Outputs a textarea with the given arguments for use with the post meta box. */
function framework_post_meta_box_textarea( $args = array(), $value = false ) {
	$name = preg_replace( "/[^A-Za-z_-]/", '-', $args['name'] ); ?>

	<tr>
		<th>
			<?php if ( $args['description'] ) : ?>
				<label for="<?php echo $name; ?>"><strong><?php echo $args['title']; ?></strong></label>
				<p class="description"><?php echo $args['description']; ?></p>
			<?php else : ?>
				<label for="<?php echo $name; ?>"><?php echo $args['title']; ?></label>
			<?php endif; ?>
		</th>

		<td>
			<textarea id="<?php echo $name; ?>" name="<?php echo $name; ?>" cols="60" rows="4" tabindex="30" style="width: 97%;"><?php echo esc_html( $value, 1 ); ?></textarea>
		</td>
	</tr>

<?php }

/* The function for saving the theme's post meta box settings. */
function framework_save_post_meta_box( $post_id ) {
	global $post;

	/* Get the theme prefix. */
	$prefix = framework_get_prefix();

	/* Verify the nonce before preceding. */
	if ( !wp_verify_nonce( $_POST["{$prefix}_{$_POST['post_type']}_meta_box_nonce"], basename( __FILE__ ) ) )
		return $post_id;

	/* Get the post type object. */
	$post_type = get_post_type_object( $_POST['post_type'] );

	/* Check if the current user has permission to edit the post. */
	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
		return $post_id;

	/* Get the post meta box arguments. */
	$metadata = framework_post_meta_box_args( $_POST['post_type'] );

	/* Loop through all of post meta box arguments. */
	foreach ( $metadata as $meta ) {

		/* Get the meta value of the custom field key. */
		$meta_value = get_post_meta( $post_id, $meta['name'], true );

		/* Get the meta value the user input. */
		$new_meta_value = stripslashes( $_POST[ preg_replace( "/[^A-Za-z_-]/", '-', $meta['name'] ) ] );

		/* If a new meta value was added and there was no previous value, add it. */
		if ( $new_meta_value && '' == $meta_value )
			add_post_meta( $post_id, $meta['name'], $new_meta_value, true );

		/* If the new meta value does not match the old value, update it. */
		elseif ( $new_meta_value && $new_meta_value != $meta_value )
			update_post_meta( $post_id, $meta['name'], $new_meta_value );

		/* If there is no new meta value but an old value exists, delete it. */
		elseif ( '' == $new_meta_value && $meta_value )
			delete_post_meta( $post_id, $meta['name'], $meta_value );

	}

}

?>