<?php

/* Archives Widget Class. */
class Framework_Widget_Archives extends WP_Widget {

	/* Set up the widget's unique name, ID, class, description, and other options. */
	function __construct() {

		/* Get the theme prefix. */
		$this->prefix = framework_get_prefix();

		/* Set up the widget options. */
		$widget_options = array(
			'classname' => 'archives',
			'description' => esc_html__( 'A monthly archive of your site\'s posts.', 'wordsmith' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width' => 200,
			'height' => 350
		);

		/* Create the widget. */
		$this->WP_Widget( "{$this->prefix}-archives", __( 'Archives', 'wordsmith' ), $widget_options, $control_options );

	}

	/* Outputs the widget based on the arguments input through the widget controls. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Arguments for the widget. */
		$args = array( 'echo' => false, 'format' => 'html', 'show_post_count' => true );
		$args['type'] = $instance['type']; 
		$args['limit'] = !empty( $instance['limit'] ) ? intval( $instance['limit'] ) : '';

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		/* If a title was input by the user, display it. */
		if ( !empty( $instance['title'] ) )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

			/* Get the archives list. */
			$archives = str_replace( array( '\r', '\n', '\t' ), '', wp_get_archives( $args ) );
			$archives = str_replace( '(', '<span class="post-data">', $archives );
			$archives = str_replace( ')', '</span><!-- post-data -->', $archives );

			echo '<ul class="xoxo archives">';
				echo $archives;
			echo '</ul><!-- .xoxo .archives -->';

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/* Updates the widget control options for the particular instance of the widget. */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['limit'] = strip_tags( $new_instance['limit'] );
		$instance['type'] = strip_tags( $new_instance['type'] );

		return $instance;
	}

	/* Displays the widget control options in the Widgets admin screen. */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Archives', 'wordsmith' ),
			'type' => 'monthly',
			'limit' => '5'
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );

		$type = array(
			'daily' => esc_attr__( 'Daily', 'wordsmith' ),
			'weekly' => esc_attr__( 'Weekly', 'wordsmith' ),
			'monthly' => esc_attr__( 'Monthly', 'wordsmith' ),
			'yearly' => esc_attr__( 'Yearly', 'wordsmith' )
		);

	?>

		<div class="widget-controls column-1">

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'limit' ); ?>"><?php _e( 'Limit:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" value="<?php echo esc_attr( $instance['limit'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e( 'Type:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>">
					<?php foreach ( $type as $option_value => $option_label ) { ?>
					<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['type'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

		</div><!-- .widget-controls -->

		<div class="clear">&nbsp;</div><!-- .clear -->

	<?php } } ?>