<?php

/* Authors Widget Class. */
class Framework_Widget_Authors extends WP_Widget {

	/* Set up the widget's unique name, ID, class, description, and other options. */
	function __construct() {

		/* Get the theme prefix. */
		$this->prefix = framework_get_prefix();

		/* Set up the widget options. */
		$widget_options = array(
			'classname' => 'authors',
			'description' => esc_html__( 'A list of your site\'s authors.', 'wordsmith' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width' => 200,
			'height' => 350
		);

		/* Create the widget. */
		$this->WP_Widget( "{$this->prefix}-authors", __( 'Authors', 'wordsmith' ), $widget_options, $control_options );

	}

	/* Outputs the widget based on the arguments input through the widget controls. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Set the $args for wp_list_authors() to the $instance array. */
		$args = $instance;

		/* Overwrite the $echo argument and set it to false. */
		$args['echo'] = false;

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		/* If a title was input by the user, display it. */
		if ( !empty( $instance['title'] ) )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

		/* Get the authors list. */
		$authors = str_replace( array( '\r', '\n', '\t' ), '', wp_list_authors( $args ) );
		$authors = str_replace( '(', '<span class="post-data">', $authors );
		$authors = str_replace( ')', '</span><!-- post-data -->', $authors );

		echo '<ul class="xoxo authors">';
			echo $authors;
		echo '</ul><!-- .xoxo .authors -->';

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/* Updates the widget control options for the particular instance of the widget. */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['order'] = strip_tags( $new_instance['order'] );
		$instance['orderby'] = strip_tags( $new_instance['orderby'] );
		$instance['number'] = strip_tags( $new_instance['number'] );

		$instance['html'] = ( isset( $new_instance['html'] ) ? 1 : 0 );
		$instance['optioncount'] = ( isset( $new_instance['optioncount'] ) ? 1 : 0 );
		$instance['show_fullname'] = ( isset( $new_instance['show_fullname'] ) ? 1 : 0 );
		$instance['hide_empty'] = ( isset( $new_instance['hide_empty'] ) ? 1 : 0 );

		return $instance;
	}

	/* Displays the widget control options in the Widgets admin screen. */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Authors', 'wordsmith' ),
			'hide_empty' => true,
			'html' => true,
			'number' => '',
			'optioncount' => true,
			'order' => 'ASC',
			'orderby' => 'display_name',
			'show_fullname' => true
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );

		$order = array( 'ASC' => esc_attr__( 'Ascending', 'wordsmith' ), 'DESC' => esc_attr__( 'Descending', 'wordsmith' ) );
		$orderby = array( 'display_name' => esc_attr__( 'Display Name', 'wordsmith' ), 'email' => esc_attr__( 'Email', 'wordsmith' ), 'ID' => esc_attr__( 'ID', 'wordsmith' ), 'nicename' => esc_attr__( 'Nice Name', 'wordsmith' ), 'post_count' => esc_attr__( 'Post Count', 'wordsmith' ), 'registered' => esc_attr__( 'Registered', 'wordsmith' ), 'url' => esc_attr__( 'URL', 'wordsmith' ), 'user_login' => esc_attr__( 'Login', 'wordsmith' ) );

	?>

		<div class="widget-controls columns-1">

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php _e( 'Order:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>">
					<?php foreach ( $order as $option_value => $option_label ) { ?>
					<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['order'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Order By:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>">
					<?php foreach ( $orderby as $option_value => $option_label ) { ?>
					<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['orderby'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>"name="<?php echo $this->get_field_name( 'number' ); ?>" value="<?php echo esc_attr( $instance['number'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'html' ); ?>">
				<input class="checkbox" id="<?php echo $this->get_field_id( 'html' ); ?>" name="<?php echo $this->get_field_name( 'html' ); ?>" type="checkbox" <?php checked( $instance['html'], true ); ?> /> <?php _e( '<acronym title="Hypertext Markup Language">HTML</acronym>?', 'wordsmith' ); ?></label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'optioncount' ); ?>">
				<input class="checkbox" id="<?php echo $this->get_field_id( 'optioncount' ); ?>" name="<?php echo $this->get_field_name( 'optioncount' ); ?>" type="checkbox" <?php checked( $instance['optioncount'], true ); ?> /> <?php _e( 'Show post count?', 'wordsmith' ); ?></label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'show_fullname' ); ?>">
				<input class="checkbox" id="<?php echo $this->get_field_id( 'show_fullname' ); ?>" name="<?php echo $this->get_field_name( 'show_fullname' ); ?>" type="checkbox" <?php checked( $instance['show_fullname'], true ); ?> /> <?php _e( 'Show full name?', 'wordsmith' ); ?></label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'hide_empty' ); ?>">
				<input class="checkbox" id="<?php echo $this->get_field_id( 'hide_empty' ); ?>" name="<?php echo $this->get_field_name( 'hide_empty' ); ?>" type="checkbox" <?php checked( $instance['hide_empty'], true ); ?> /> <?php _e( 'Hide empty?', 'wordsmith' ); ?></label>
			</p>

		</div><!-- .widget-controls -->

		<div class="clear">&nbsp;</div><!-- .clear -->

	<?php } } ?>