<?php

/* Dribbble Widget Class. */
class Framework_Widget_Dribbble extends WP_Widget {

	/* Set up the widget's unique name, ID, class, description, and other options. */
	function __construct() {

		/* Get the theme information. */
		$this->name = wp_get_theme();

		/* Get the theme prefix. */
		$this->prefix = framework_get_prefix();

		/* Set up the widget options. */
		$widget_options = array(
			'classname' => 'dribbble',
			'description' => esc_html__( 'Display your latest Dribbble shots.', 'wordsmith' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width' => 200,
			'height' => 350
		);

		/* Create the widget. */
		$this->WP_Widget( "{$this->prefix}-dribbble", __( 'Dribbble', 'wordsmith' ), $widget_options, $control_options );

	}

	/* Outputs the widget based on the arguments input through the widget controls. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Arguments for the widget. */
		$args['dribbble_username'] = strip_tags( $instance['dribbble_username'] );
		$args['dribbble_feed_count'] = strip_tags( $instance['dribbble_feed_count'] );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		/* If a title was input by the user, display it. */
		if ( !empty( $instance['title'] ) )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

	?>

	<?php
		if ( function_exists( 'fetch_feed' ) ):
			$rss = fetch_feed( 'feed://dribbble.com/' . esc_html( $instance['dribbble_username'] ) . '/shots.rss' );
			add_filter( 'wp_feed_cache_transient_lifetime', create_function( '$a', 'return 1800;' ) );
			if ( !is_wp_error( $rss ) ) : 
				$items = $rss->get_items( 0, $rss->get_item_quantity( $instance['dribbble_feed_count'] ) ); 
			endif;
		endif;
	?>

	<?php if ( !empty( $items ) ): ?>

		<ul class="dribbble-shots">

			<?php
				foreach ( $items as $item ) :
					$title = esc_attr( $item->get_title() );
					$link = esc_url( $item->get_permalink() );
					$date = esc_attr( $item->get_date( get_option( 'date_format' ) ) );
					$description = esc_html( $item->get_description() );
					preg_match( "/src=\"(http.*(jpg|jpeg|gif|png))/", $item->get_description(), $image );
			?>

			<li class="dribbble-shot">

				<a href="<?php echo esc_url( $item->get_permalink() ); ?>"><img class="dribbble-image" src="<?php echo $image[1]; ?>" alt="<?php echo esc_attr( $item->get_title() ); ?>" /></a>

			</li><!-- .dribbble-shot -->

			<?php endforeach;?>

		</ul><!-- .dribbble-shots -->

	<?php endif; ?>

	<?php

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/* Updates the widget control options for the particular instance of the widget. */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['dribbble_feed_count'] = intval( $new_instance['dribbble_feed_count'] );
		$instance['dribbble_username'] = strip_tags( $new_instance['dribbble_username'] );

		return $instance;
	}

	/* Displays the widget control options in the Widgets admin screen. */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Dribbble', 'wordsmith' ),
			'dribbble_username' => 'dribbble',
			'dribbble_feed_count' => '6'
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );

	?>

		<div class="widget-controls column-1">

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'dribbble_username' ); ?>"><?php _e( 'Username:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'dribbble_username' ); ?>" name="<?php echo $this->get_field_name( 'dribbble_username' ); ?>" value="<?php echo esc_attr( $instance['dribbble_username'] ); ?>" type="text"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'dribbble_feed_count' ); ?>"><?php _e( 'Limit:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'dribbble_feed_count' ); ?>" name="<?php echo $this->get_field_name( 'dribbble_feed_count' ); ?>" value="<?php echo esc_attr( $instance['dribbble_feed_count'] ); ?>" type="text" />
			</p>

		</div><!-- .widget-controls -->

		<div class="clear">&nbsp;</div><!-- .clear -->

	<?php } } ?>