<?php

/* Flickr Gallery Widget Class. */
class Framework_Widget_Flickr_Gallery extends WP_Widget {

	/* Set up the widget's unique name, ID, class, description, and other options. */
	function __construct() {

		/* Get the theme prefix. */
		$this->prefix = framework_get_prefix();

		/* Set up the widget options. */
		$widget_options = array(
			'classname' => 'flickr-gallery',
			'description' => esc_html__( 'Display your flickr images.', 'wordsmith' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width' => 200,
			'height' => 350
		);

		/* Create the widget. */
		$this->WP_Widget( "{$this->prefix}-flickr-gallery", __( 'Flickr Gallery', 'wordsmith' ), $widget_options, $control_options );

	}

	/* Outputs the widget based on the arguments input through the widget controls. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		/* If a title was input by the user, display it. */
		if ( !empty( $instance['title'] ) )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

		$args['id'] = $instance['id'];
		$args['limit'] = $instance['limit'];
		$args['type'] = $instance['type'];
		$args['display'] = $instance['display'];

		echo '<script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count=' . $args['limit'] . '&amp;display=' . $args['display'] . '&amp;size=s&amp;layout=x&amp;source=' . $args['type'] . '&amp;' . $args['type'] . '=' . $args['id'] . '"></script>';

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/* Updates the widget control options for the particular instance of the widget. */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['id'] = strip_tags( $new_instance['id'] );
		$instance['limit'] = $new_instance['limit'];
		$instance['type'] = $new_instance['type'];
		$instance['display'] = $new_instance['display'];

		return $instance;
	}

	/* Displays the widget control options in the Widgets admin screen. */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Flickr Gallery', 'wordsmith' ),
			'id' => '1045413@N25',
			'limit' => '6',
			'type' => 'group',
			'display' => 'latest'
		);

		$instance = wp_parse_args( (array) $instance, $defaults ); 

		$limit = array(
			'3' => esc_attr__( '3', 'wordsmith' ),
			'6' => esc_attr__( '6', 'wordsmith' ),
			'9' => esc_attr__( '9', 'wordsmith' )
		);

		$type = array(
			'group' => esc_attr__( 'Group', 'wordsmith' ),
			'user' => esc_attr__( 'User', 'wordsmith' )
		);

		$display = array(
			'latest' => esc_attr__( 'Latest', 'wordsmith' ),
			'random' => esc_attr__( 'Random', 'wordsmith' )
		);

	?>

		<div class="widget-controls columns-1">

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'id' ); ?>"><?php printf( __( 'Flickr ID (<a href="%1$s">idGettr</a>):', 'wordsmith' ), 'http://idgettr.com' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'id' ); ?>"name="<?php echo $this->get_field_name( 'id' ); ?>" value="<?php echo esc_attr( $instance['id'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'limit' ); ?>"><?php _e( 'Limit:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>">
					<?php foreach ( $limit as $option_value => $option_label ) { ?>
					<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['limit'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e( 'Type:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>">
					<?php foreach ( $type as $option_value => $option_label ) { ?>
					<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['type'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'display' ); ?>"><?php _e( 'Display:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'display' ); ?>" name="<?php echo $this->get_field_name( 'display' ); ?>">
					<?php foreach ( $display as $option_value => $option_label ) { ?>
					<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['display'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

		</div><!-- .widget-controls -->

		<div class="clear">&nbsp;</div><!-- .clear -->

	<?php } } ?>