<?php

/* Image Gallery Widget Class. */
class Framework_Widget_Image_Gallery extends WP_Widget {

	/* Set up the widget's unique name, ID, class, description, and other options. */
	function __construct() {

		/* Get the theme prefix. */
		$this->prefix = framework_get_prefix();

		/* Set up the widget options. */
		$widget_options = array(
			'classname' => 'image-gallery',
			'description' => esc_html__( 'Display your site\'s images.', 'wordsmith' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width' => 200,
			'height' => 350
		);

		/* Create the widget. */
		$this->WP_Widget( "{$this->prefix}-image-gallery", __( 'Image Gallery', 'wordsmith' ), $widget_options, $control_options );

	}

	/* Outputs the widget based on the arguments input through the widget controls. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		/* If a title was input by the user, display it. */
		if ( !empty( $instance['title'] ) )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

		/* Query images. */
		$loop = new WP_Query(
			array(
				'orderby' => 'parent',
				'post_mime_type' => 'image',
				'posts_per_page' => intval( $instance['posts_per_page'] ),
				'post_status' => 'inherit',
				'post_type' => 'attachment'
			)
		);

		echo '<ul>';

			if ( $loop->have_posts() ) : while ( $loop->have_posts() ) : $loop->the_post();

				echo '<li>';

					echo wp_get_attachment_link( get_the_ID(), 'thumbnail', true );

				echo '</li>';

			endwhile; else :

				echo '<div class="no-results not-found">' . __( 'There are currently no images available.', 'wordsmith' ) . '</div>';

			endif;

		echo '</ul>';

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/* Updates the widget control options for the particular instance of the widget. */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['posts_per_page'] = strip_tags( $new_instance['posts_per_page'] );

		return $instance;
	}

	/* Displays the widget control options in the Widgets admin screen. */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Image Gallery', 'wordsmith' ),
			'posts_per_page' => 6,
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );

	?>

		<div class="widget-controls column-1">

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'posts_per_page' ); ?>"><?php _e( 'Limit:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'posts_per_page' ); ?>"name="<?php echo $this->get_field_name( 'posts_per_page' ); ?>" value="<?php echo esc_attr( $instance['posts_per_page'] ); ?>" type="text" />
			</p>

		</div><!-- .widget-controls -->

		<div class="clear">&nbsp;</div><!-- .clear -->

	<?php } } ?>