<?php

/* Comments Widget Class. */
class Framework_Widget_Recent_Comments extends WP_Widget {

	/* Set up the widget's unique name, ID, class, description, and other options. */
	function __construct() {

		/* Get the theme prefix. */
		$this->prefix = framework_get_prefix();

		/* Set up the widget options. */
		$widget_options = array(
			'classname' => 'recent-comments',
			'description' => esc_html__( 'Display your site\'s recent comments.', 'wordsmith' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width' => 200,
			'height' => 350
		);

		/* Create the widget. */
		$this->WP_Widget( "{$this->prefix}-recent-comments", __( 'Recent Comments', 'wordsmith' ), $widget_options, $control_options );

	}

	/* Displays the widget on the front end. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Arguments for the widget. */
		$args['commenters_avatar'] = $instance['commenters_avatar'];
		$args['comment_count'] = intval( $instance['comment_count'] );
		$args['commenters_name'] = $instance['commenters_name'];

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		/* If a title was input by the user, display it. */
		if ( !empty( $instance['title'] ) )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

		$comments = get_comments( apply_filters( 'widget_comments_args', array( 'number' => $args['comment_count'], 'post_status' => 'publish', 'status' => 'approve', ) ) );

		echo '<ul class="xoxo comments">';

			if ( $comments ) {

				foreach ( (array) $comments as $comment ) {

					if ( get_comment_type( $comment->comment_ID ) == 'comment' ) :

						echo '<li>';

							if ( $instance['commenters_avatar'] == false ) :
								echo get_avatar( $comment, '45' );
							endif;

							echo '<span class="comment-content">';

								if ( $instance['commenters_name'] == false ) :
									echo '<span class="comment-author">' . get_comment_author( $comment->comment_ID ) . '</span>';
								endif;

								echo '<a href="' . get_comment_link( $comment->comment_ID ) . '">' . get_the_title( $comment->comment_post_ID ) . '</a>';

							echo '</span><!-- .comment-content -->';

						echo '</li>';

					endif;
				}
			}

		echo '</ul><!-- .xoxo .comments -->';

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/* Updates the widget control options for the particular instance of the widget. */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['commenters_avatar'] = ( isset( $new_instance['commenters_avatar'] ) ? 1 : 0 );
		$instance['comment_count'] = strip_tags( $new_instance['comment_count'] );
		$instance['commenters_name'] = ( isset( $new_instance['commenters_name'] ) ? 1 : 0 );

		return $instance;
	}

	/* Displays the widget control options in the Widgets admin screen. */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Recent Comments', 'wordsmith' ),
			'commenters_avatar' => '',
			'comment_count' => '4',
			'commenters_name' => ''
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );

	?>

		<div class="widget-controls column-1">

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'comment_count' ); ?>"><?php _e( 'Limit:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'comment_count' ); ?>" name="<?php echo $this->get_field_name( 'comment_count' ); ?>" value="<?php echo esc_attr( $instance['comment_count'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'commenters_avatar' ); ?>">
				<input class="checkbox" id="<?php echo $this->get_field_id( 'commenters_avatar' ); ?>" name="<?php echo $this->get_field_name( 'commenters_avatar' ); ?>" type="checkbox" <?php checked( $instance['commenters_avatar'], true ); ?> /> <?php _e( 'Hide commenters avatar?', 'wordsmith' ); ?></label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'commenters_name' ); ?>">
				<input class="checkbox" id="<?php echo $this->get_field_id( 'commenters_name' ); ?>" name="<?php echo $this->get_field_name( 'commenters_name' ); ?>" type="checkbox" <?php checked( $instance['commenters_name'], true ); ?> /> <?php _e( 'Hide commenters name?', 'wordsmith' ); ?></label>
			</p>

		</div><!-- .widget-controls -->

		<div class="clear">&nbsp;</div><!-- .clear -->

	<?php } } ?>