<?php

/* Posts Widget Class. */
class Framework_Widget_Recent_Posts extends WP_Widget {

	/* Set up the widget's unique name, ID, class, description, and other options. */
	function __construct() {

		/* Get the theme prefix. */
		$this->prefix = framework_get_prefix();

		/* Set up the widget options. */
		$widget_options = array(
			'classname' => 'recent-posts',
			'description' => esc_html__( 'Display your site\'s recent posts.', 'wordsmith' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width' => 200,
			'height' => 350
		);

		/* Create the widget. */
		$this->WP_Widget( "{$this->prefix}-recent-posts", __( 'Recent Posts', 'wordsmith' ), $widget_options, $control_options );

	}

	/* Outputs the widget based on the arguments input through the widget controls. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Arguments for the widget. */
		$args['category'] = $instance['category'];
		$args['order'] = $instance['order'];
		$args['orderby'] = $instance['orderby'];

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		/* If a title was input by the user, display it. */
		if ( !empty( $instance['title'] ) )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

	?>

	<?php

		if ( $instance['sort_most_viewed'] == false ) {

			$wp_query = new WP_Query(
				apply_filters( 'widget_posts_args',
					array(
						'cat' => $instance['category'],
						'order' => $instance['order'],
						'orderby' => $instance['orderby'],
						'post__not_in' => get_option( 'sticky_posts' ),
						'posts_per_page' => intval( $instance['limit'] ),
						'post_status' => 'publish',
						'tax_query' => array(
							array(
								'field' => 'slug',
								'operator' => 'NOT IN',
								'taxonomy' => 'post_format',
								'terms' => array( 'post-format-aside', 'post-format-audio', 'post-format-chat', 'post-format-gallery', 'post-format-image', 'post-format-link', 'post-format-link', 'post-format-quote', 'post-format-status', 'post-format-video' )
							)
						)
					)
				)
			);

		} else {

			$wp_query = new WP_Query(
				apply_filters( 'widget_posts_args',
					array(
						'cat' => $instance['category'],
						'meta_key' => 'Views',
						'order' => $instance['order'],
						'orderby' => 'meta_value_num',
						'post__not_in' => get_option( 'sticky_posts' ),
						'posts_per_page' => intval( $instance['limit'] ),
						'post_status' => 'publish',
						'tax_query' => array(
							array(
								'field' => 'slug',
								'operator' => 'NOT IN',
								'taxonomy' => 'post_format',
								'terms' => array( 'post-format-aside', 'post-format-audio', 'post-format-chat', 'post-format-gallery', 'post-format-image', 'post-format-link', 'post-format-link', 'post-format-quote', 'post-format-status', 'post-format-video' )
							)
						)
					)
				)
			);

		}

	?>

	<?php if ( $wp_query->have_posts() ) : ?>

	<ul class="xoxo posts">

		<?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>

			<li>

				<header class="post-title">
					<?php printf( '<a href="%1$s">%2$s</a>', get_permalink(), get_the_title() ); ?>
				</header><!-- .post-meta -->

				<div class="post-meta">
					<span class="published"><?php printf( '%1$s', get_the_time( get_option( 'date_format' ) ) ); ?></span>
				</div><!-- .post-meta -->

				<?php
					if ( has_excerpt() ) :
						echo '<div class="post-summary">' . get_the_excerpt() . '</div><!-- .post-summary -->';
					endif;
				?>

			</li>

		<?php endwhile; wp_reset_query(); ?>

	</ul><!-- .xoxo .posts -->

	<?php

		endif;

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/* Updates the widget control options for the particular instance of the widget. */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['category'] = strip_tags( $new_instance['category'] );
		$instance['orderby'] = $new_instance['orderby'];
		$instance['limit'] = strip_tags( $new_instance['limit'] );

		return $instance;
	}

	/* Displays the widget control options in the Widgets admin screen. */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => __( 'Recent Posts', 'wordsmith' ),
			'order' => 'DESC',
			'orderby' => 'date',
			'limit' => '4'
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );

		/* Select element options. */
		$order = array( 'ASC' => esc_attr__( 'Ascending', 'wordsmith' ), 'DESC' => esc_attr__( 'Descending', 'wordsmith' ) );
		$orderby = array( 'author' => esc_attr__( 'Author', 'wordsmith' ), 'comment_count' => esc_attr__( 'Comment Count', 'wordsmith' ), 'date' => esc_attr__( 'Date', 'wordsmith' ), 'ID' => esc_attr__( 'ID', 'wordsmith' ), 'name' => esc_attr__( 'Name', 'wordsmith' ), 'rand' => esc_attr__( 'Random', 'wordsmith' ), 'title' => esc_attr__( 'Title', 'wordsmith' ) );

	?>

		<div class="widget-controls columns-1">

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" type="text" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Category:', 'wordsmith' ); ?></label>
				<?php
					wp_dropdown_categories(
						array(
							'class' => 'widefat',
							'id' => $this->get_field_id( 'category' ),
							'name' => $this->get_field_name( 'category' ),
							'selected' => $instance['category'],
							'show_option_all' => '&ndash; Select &ndash;',
						)
					);
				?>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php _e( 'Order:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>">
					<?php foreach ( $order as $option_value => $option_label ) { ?>
						<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['order'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Order By:', 'wordsmith' ); ?></label>
				<select class="widefat" id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>">
					<?php foreach ( $orderby as $option_value => $option_label ) { ?>
						<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $instance['orderby'], $option_value ); ?>><?php echo esc_html( $option_label ); ?></option>
					<?php } ?>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'limit' ); ?>"><?php _e( 'Limit:', 'wordsmith' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" value="<?php echo esc_attr( $instance['limit'] ); ?>" type="text" />
			</p>

		</div><!-- .widget-controls -->

		<div class="clear">&nbsp;</div><!-- .clear -->

	<?php } } ?>