<?php

/* Filter the comment form defaults. */
add_filter( 'comment_form_defaults', 'framework_comment_form_args' );

/* Arguments for the wp_list_comments_function() used in comments.php. */
function framework_list_comments_args() {

	/* Set the default arguments for listing comments. */
	$args = array(
		'style' => 'ol',
		'type' => 'all',
		'callback' => 'framework_comments_callback',
		'end-callback' => 'framework_comments_end_callback'
	);

	/* Return the arguments and allow devs to overwrite them. */
	return apply_atomic( 'list_comments_args', $args );

}

/* Uses the $comment_type to determine which comment template should be used. */
function framework_comments_callback( $comment, $args, $depth ) {
	global $framework;
	$GLOBALS['comment'] = $comment;
	$GLOBALS['comment_depth'] = $depth;

	/* Get the comment type of the current comment. */
	$comment_type = get_comment_type( $comment->comment_ID );

	/* Create an empty array if the comment template array is not set. */
	if ( !isset( $framework->comment_template) || !is_array( $framework->comment_template ) )
		$framework->comment_template = array();

	/* Check if a template has been provided for the specific comment type.  If not, get the template. */
	if ( !isset( $framework->comment_template[$comment_type] ) ) {

		/* Create an array of template files to look for. */
		$templates = array( "comment-{$comment_type}.php" );

		/* If the comment type is a 'pingback' or 'trackback', allow the use of 'comment-ping.php'. */
		if ( 'pingback' == $comment_type || 'trackback' == $comment_type )
			$templates[] = 'comment-ping.php';

		/* Add the fallback 'comment.php' template. */
		$templates[] = 'comment.php';

		/* Locate the comment template. */
		$template = locate_template( $templates );

		/* Set the template in the comment template array. */
		$framework->comment_template[$comment_type] = $template;
	}

	/* If a template was found, load the template. */
	if ( !empty( $framework->comment_template[$comment_type] ) )
		require( $framework->comment_template[$comment_type] );

}

/* Ends the display of individual comments. */
function framework_comments_end_callback() {
	echo '</li><!-- .comment -->';
}

/* Filters the WordPress comment_form() function that was added in WordPress 3.0. */
function framework_comment_form_args( $args ) {
	global $user_identity;

	/* Get the current commenter. */
	$commenter = wp_get_current_commenter();

	/* Create the required <span> and <input> element class. */
	$req = ( ( get_option( 'require_name_email' ) ) ? ' <span class="required">' . __( 'Required', 'wordsmith' ) . '</span>' : '' );
	$input_class = ( ( get_option( 'require_name_email' ) ) ? ' req' : '' );

	/* Sets up the default comment form fields. */
	$fields = array(
		'author' => '<p class="form-author' . esc_attr( $input_class ) . '"><label for="author">' . __( 'Name', 'wordsmith' ) . $req . '</label> <input class="text-input" id="author" name="author" size="40" type="text" /></p>',
		'email' => '<p class="form-email' . esc_attr( $input_class ) . '"><label for="email">' . __( 'Email', 'wordsmith' ) . $req . '</label> <input class="text-input" id="email" name="email" size="40" type="text" /></p>',
		'url' => '<p class="form-url"><label for="url">' . __( 'Website', 'wordsmith' ) . '</label> <input class="text-input" id="url" name="url" size="40" type="text" /></p>'
	);

	/* Sets the default arguments for displaying the comment form. */
	$args = array(
		'fields' => apply_filters( 'comment_form_default_fields', $fields ),
		'comment_field' => '<p class="form-textarea req"><label for="comment">' . __( 'Comment', 'wordsmith' ) . '</label><textarea name="comment" id="comment" cols="60" rows="10"></textarea></p>',
		'must_log_in' => '<p class="alert must-log-in">' . sprintf( __( 'You must be <a href="%1$s">logged in</a> to post a comment.', 'wordsmith' ), wp_login_url( get_permalink() ) ) . '</p>',
		'logged_in_as' => '<p class="log-in-out"><span class="logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s">%2$s</a>', 'wordsmith' ), admin_url( 'profile.php' ), esc_attr( $user_identity ) ) . '</span> <a class="log-out-link" href="' . wp_logout_url( get_permalink() ) . '">' . __( 'Sign Out', 'wordsmith' ) . '</a></p>',
		'comment_notes_before' => '',
		'comment_notes_after' => '',
		'id_form' => 'commentform',
		'id_submit' => 'submit',
		'title_reply' => '<span>' . __( 'Leave a Reply', 'wordsmith' ) . '</span>',
		'title_reply_to' => '<span>' . __( 'Leave a Reply to %s', 'wordsmith' ) . '</span>',
		'cancel_reply_link' => __( 'Cancel', 'wordsmith' ),
		'label_submit' => __( 'Post Comment', 'wordsmith' ),
	);

	/* Return the arguments for displaying the comment form. */
	return $args;

}

?>