<?php

/* Load scripts. */
add_action( 'wp_enqueue_scripts', 'framework_enqueue_script' );

/* Load styles. */
add_action( 'wp_enqueue_scripts', 'framework_enqueue_style' );

/* Add all image sizes to the image editor to insert into post. */
add_filter( 'image_size_names_choose', 'framework_image_size_names_choose' );

/* Loads JavaScript at an appropriate time. */
function framework_enqueue_script() {

	/* Don't load any scripts in the admin. */
	if ( is_admin() )
		return;

	/* Load jQuery script. */
	wp_enqueue_script( array( 'jquery' ) );

	/* Load comment reply script. */
	if ( is_singular() && get_option( 'thread_comments' ) && comments_open() )
		wp_enqueue_script( 'comment-reply' );

	/* Load custom script. */
	wp_enqueue_script( 'custom', esc_url( trailingslashit( FRAMEWORK_JS ) . 'custom.js' ), array( 'jquery' ), null, true );

	/* Load media element script. */
	wp_enqueue_script( 'media-element', esc_url( trailingslashit( FRAMEWORK_JS ) . 'mediaelement/mediaelement-and-player.js' ), array( 'jquery' ), null, true );

	/* Load modernizr script. */
	wp_enqueue_script( 'modernizr', esc_url( trailingslashit( FRAMEWORK_JS ) . 'modernizr.js' ), array( 'jquery' ), null, true );

}

/* Loads CSS at an appropriate time. */
function framework_enqueue_style() {
	global $wp_query;

	/* If is admin, don't load styles. */
	if ( is_admin() )
		return;

	/* Load color stylesheet. */
	wp_enqueue_style( framework_get_setting( 'color_stylesheet' ), esc_url( trailingslashit( FRAMEWORK_URI ) . 'color/' . framework_get_setting( 'color_stylesheet' ) . '.css' ), false, null, 'screen' );

	/* Load Google font stylesheet. */
	if ( framework_get_setting( 'google_font_name' ) )
		wp_enqueue_style( 'google-font', esc_url( 'https://fonts.googleapis.com/css?family=' . framework_get_setting( 'google_font_name' ) ), false, null, 'screen' );

	/* Load flexslider CSS. */
	wp_enqueue_style( 'flexslider', esc_url( trailingslashit( FRAMEWORK_CSS ) . 'flexslider.css' ), false, null, 'screen' );

	/* Load media element CSS. */
	wp_enqueue_style( 'media-element', esc_url( trailingslashit( FRAMEWORK_JS ) . 'mediaelement/mediaelementplayer.css' ), false, null, 'screen' );

}

/* Adds theme/plugin custom images sizes added with add_image_size() to the image uploader/editor. */
function framework_image_size_names_choose( $sizes ) {

	/* Get all intermediate image sizes. */
	$intermediate_sizes = get_intermediate_image_sizes();
	$add_sizes = array();

	/* Loop through each of the intermediate sizes, adding them to the $add_sizes array. */
	foreach ( $intermediate_sizes as $size )
		$add_sizes[$size] = $size;

	/* Merge the original array, keeping it intact, with the new array of image sizes. */
	$sizes = array_merge( $add_sizes, $sizes );

	/* Return the new sizes plus the old sizes back. */
	return $sizes;

}

?>