<?php

/* Register widget areas. */
add_action( 'widgets_init', 'framework_register_sidebars' );

/* Filter the sidebar widgets. */
add_filter( 'sidebars_widgets', 'framework_disable_sidebars' );

/* Disables sidebars if viewing a one-column page. */
function framework_disable_sidebars( $sidebars_widgets ) {

	if ( current_theme_supports( 'theme-layouts' ) && !is_admin() ) {
		if ( 'layout-1c' == theme_layouts_get_layout() ) {
			$sidebars_widgets['primary'] = false;
			$sidebars_widgets['secondary'] = false;
		}
	}

	return $sidebars_widgets;
}

/* Registers the default framework dynamic sidebars. */
function framework_register_sidebars() {

	/* Get the theme-supported sidebars. */
	$supported_sidebars = get_theme_support( 'widget-areas' );

	/* If the theme doesn't add support for any sidebars, return. */
	if ( !is_array( $supported_sidebars[0] ) )
		return;

	/* Get the available core framework sidebars. */
	$core_sidebars = framework_get_sidebars();

	/* Loop through the supported sidebars. */
	foreach ( $supported_sidebars[0] as $sidebar ) {

		/* Make sure the given sidebar is one of the core sidebars. */
		if ( isset( $core_sidebars[$sidebar] ) ) {

			/* Set up some default sidebar arguments. */
			$defaults = array(
				'before_widget'	=> '<aside id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-wrap widget-inside">',
				'after_widget'	=> '</div></aside>',
				'before_title'	=> '<h3 class="widget-title">',
				'after_title'	=> '</h3>'
			);

			/* Parse the sidebar arguments and defaults. */
			$args = wp_parse_args( $core_sidebars[$sidebar], $defaults );

			/* If no 'id' was given, use the $sidebar variable and sanitize it. */
			$args['id'] = ( isset( $args['id'] ) ? sanitize_key( $args['id'] ) : sanitize_key( $sidebar ) );

			/* Register the sidebar. */
			register_sidebar( $args );
		}
	}
}

/* Returns an array of the core framework's available sidebars for use in themes.  */
function framework_get_sidebars() {

	/* Set up an array of sidebars. */
	$sidebars = array(
		'primary' => array(
			'name' => __( 'Primary', 'wordsmith' ),
			'description' => __( 'The main (primary) widget area, most often used as a sidebar.', 'wordsmith' )
		),

		'secondary' => array(
			'name' =>	__( 'Secondary', 'sidebar', 'wordsmith' ),
			'description' =>	__( 'The second most important widget area, most often used as a secondary sidebar.', 'wordsmith' ),
		),

		'subsidiary' => array(
			'name' => __( 'Subsidiary 3 Columns', 'wordsmith' ),
			'description' => __( 'A widget area loaded in the footer of the site.', 'wordsmith' ),
		),

		'subsidiary-4c' => array(
			'name' => __( 'Subsidiary 4 Columns', 'wordsmith' ),
			'description' => __( 'A widget area loaded in the footer of the site.', 'wordsmith' ),
		),

		'before-content' => array(
			'name' => __( 'Before Content', 'wordsmith' ),
			'description' => __( 'Loaded before the page\'s main content area.', 'wordsmith' ),
		),

		'after-content' => array(
			'name' => __( 'After Content', 'wordsmith' ),
			'description' => __( 'Loaded after the page\'s main content area.', 'wordsmith' ),
		),

		'after-singular' => array(
			'name' => __( 'After Singular', 'wordsmith' ),
			'description' => __( 'Loaded on singular post views before the comments area.', 'wordsmith' ),
		),

		'shelf' => array(
			'name' => __( 'Shelf', 'wordsmith' ),
			'description' => __( 'Loaded at the top of the site, above the header.', 'wordsmith' ),
		),

		'error-404-template' => array(
			'name' => __( '404 Template', 'wordsmith' ),
			'description' => __( 'Replaces the default 404 error page content.', 'wordsmith' ),
		)

	);

	/* Return the sidebars. */
	return $sidebars;
}

?>